@@ -1,9 +1,7 @@
 # Break down the item meta data with a data frame format into a list format
 # This function was developed by referring to the output format of "as.irt.pars()"
 # function in the plink (Weeks, 2010) R package.
-#' @import purrr
 breakdown <- function(x) {
-
   # extract the id information
   id <- x$id
 
@@ -18,14 +16,17 @@ breakdown <- function(x) {
   pars <- data.matrix(x[, 4:ncol(x)])
 
   # classify the items into each of the models
-  item <- purrr::map(.x = uni.mod, ~{which(model == .x)})
+  item <- purrr::map(.x = uni.mod, ~ {
+    which(model == .x)
+  })
   names(item) <- uni.mod
 
   # total number of items
   nitem <- nrow(x)
 
   # create a list by combining all extracted information
-  list(id = id, cats=cats, pars = pars, model = model,
-       item = item, nitem = nitem)
-
+  list(
+    id = id, cats = cats, pars = pars, model = model,
+    item = item, nitem = nitem
+  )
 }
