@@ -126,7 +126,7 @@
 #' flex_sam <- system.file("extdata", "flexmirt_sample-prm.txt", package = "irtQ")
 #'
 #' # select the item metadata
-#' x <- bring.flexmirt(file=flex_sam, "par")$Group1$full_df
+#' x <- bring.flexmirt(file = flex_sam, "par")$Group1$full_df
 #'
 #' # modify the item metadata so that some items follow 1PLM, 2PLM and GPCM
 #' x[c(1:3, 5), 3] <- "1PLM"
@@ -138,80 +138,84 @@
 #'
 #' # generate examinees' abilities from N(0, 1)
 #' set.seed(23)
-#' score <- rnorm(500, mean=0, sd=1)
+#' score <- rnorm(500, mean = 0, sd = 1)
 #'
 #' # simulate the response data
-#' data <- simdat(x=x, theta=score, D=1)
+#' data <- simdat(x = x, theta = score, D = 1)
 #'
 #' \donttest{
 #' # 1) item parameter estimation: constrain the slope parameters of the 1PLM to be equal
-#' (mod1 <- est_item(x, data, score, D=1, fix.a.1pl=FALSE, use.gprior=TRUE,
-#'                   gprior=list(dist="beta", params=c(5, 17)), use.startval=FALSE))
+#' (mod1 <- est_item(x, data, score,
+#'   D = 1, fix.a.1pl = FALSE, use.gprior = TRUE,
+#'   gprior = list(dist = "beta", params = c(5, 17)), use.startval = FALSE
+#' ))
 #' summary(mod1)
 #'
 #' # extract the item parameter estimates
-#' getirt(mod1, what="par.est")
+#' getirt(mod1, what = "par.est")
 #'
 #' # 2) item parameter estimation: fix the slope parameters of the 1PLM to 1
-#' (mod2 <- est_item(x, data, score, D=1, fix.a.1pl=TRUE, a.val.1pl=1, use.gprior=TRUE,
-#'                   gprior=list(dist="beta", params=c(5, 17)), use.startval=FALSE))
+#' (mod2 <- est_item(x, data, score,
+#'   D = 1, fix.a.1pl = TRUE, a.val.1pl = 1, use.gprior = TRUE,
+#'   gprior = list(dist = "beta", params = c(5, 17)), use.startval = FALSE
+#' ))
 #' summary(mod2)
 #'
 #' # extract the standard error estimates
-#' getirt(mod2, what="se.est")
+#' getirt(mod2, what = "se.est")
 #'
 #' # 3) item parameter estimation: fix the guessing parameters of the 3PLM to 0.2
-#' (mod3 <- est_item(x, data, score, D=1, fix.a.1pl=TRUE, fix.g=TRUE, a.val.1pl=1, g.val=.2,
-#'                   use.startval=FALSE))
+#' (mod3 <- est_item(x, data, score,
+#'   D = 1, fix.a.1pl = TRUE, fix.g = TRUE, a.val.1pl = 1, g.val = .2,
+#'   use.startval = FALSE
+#' ))
 #' summary(mod3)
 #'
 #' # extract both item parameter and standard error estimates
-#' getirt(mod2, what="estimates")
-#'
+#' getirt(mod2, what = "estimates")
 #' }
 #'
-#' @import purrr
+#' @importFrom Matrix sparseMatrix
 #' @import dplyr
-#' @importFrom Matrix bdiag sparseMatrix
 #' @export
 #'
-est_item <- function(x=NULL, data, score, D=1, model=NULL, cats=NULL, item.id=NULL, fix.a.1pl=FALSE, fix.a.gpcm=FALSE,
-                     fix.g=FALSE, a.val.1pl=1, a.val.gpcm=1, g.val=.2, use.aprior=FALSE, use.bprior=FALSE, use.gprior=TRUE,
-                     aprior=list(dist="lnorm", params=c(0, 0.5)), bprior=list(dist="norm", params=c(0.0, 1.0)),
-                     gprior=list(dist="beta", params=c(5, 17)), missing=NA, use.startval=FALSE,
-                     control=list(eval.max=500, iter.max=500), verbose=TRUE) {
-
+est_item <- function(x = NULL, data, score, D = 1, model = NULL, cats = NULL, item.id = NULL, fix.a.1pl = FALSE, fix.a.gpcm = FALSE,
+                     fix.g = FALSE, a.val.1pl = 1, a.val.gpcm = 1, g.val = .2, use.aprior = FALSE, use.bprior = FALSE, use.gprior = TRUE,
+                     aprior = list(dist = "lnorm", params = c(0, 0.5)), bprior = list(dist = "norm", params = c(0.0, 1.0)),
+                     gprior = list(dist = "beta", params = c(5, 17)), missing = NA, use.startval = FALSE,
+                     control = list(eval.max = 500, iter.max = 500), verbose = TRUE) {
   # check start time
   start.time <- Sys.time()
 
   # match.call
   cl <- match.call()
 
-  ##-------------------------------------------------------------------------------------------------------
+  ## -------------------------------------------------------------------------------------------------------
   ## 1. preparation of item parameter estimation
-  if(verbose) {
-    cat("Starting...", '\n')
+  if (verbose) {
+    cat("Starting...", "\n")
   }
 
   # check if the starting values are available
-  if(use.startval & is.null(x)) {
-    stop(paste0("To use starting values for item parameter estimation, \n",
-                "the item metadata must be specified in the argument 'x'."), call.=FALSE)
+  if (use.startval & is.null(x)) {
+    stop(paste0(
+      "To use starting values for item parameter estimation, \n",
+      "the item metadata must be specified in the argument 'x'."
+    ), call. = FALSE)
   }
 
   # transform a data set to data.frame
-  if(is.vector(data)) {
+  if (is.vector(data)) {
     data <- data.frame(X1 = data, stringsAsFactors = FALSE)
   } else {
     data <- data.frame(data, stringsAsFactors = FALSE)
   }
 
   # extract information about the number of score categories and models
-  if(verbose) {
-    cat("Parsing input...", '\n')
+  if (verbose) {
+    cat("Parsing input...", "\n")
   }
-  if(!is.null(x)) {
-
+  if (!is.null(x)) {
     # confirm and correct all item metadata information
     x <- confirm_df(x)
 
@@ -220,35 +224,33 @@ est_item <- function(x=NULL, data, score, D=1, model=NULL, cats=NULL, item.id=NU
 
     # extract model names for all items
     model <- x$model
-
   } else {
-
     # make the model names as upper cases
     model <- toupper(model)
 
     # when a character string scalar is provided in the model argument
     # create a vector of the same model names
-    if(length(model) == 1) {
+    if (length(model) == 1) {
       model <- rep(model, ncol(data))
     }
 
     # check if the score category information is provided in the cats argument
-    if(is.null(cats)) {
-      if(all(model %in% c("1PLM", "2PLM", "3PLM", "DRM"))) {
+    if (is.null(cats)) {
+      if (all(model %in% c("1PLM", "2PLM", "3PLM", "DRM"))) {
         cats <- rep(2, ncol(data))
       } else {
-        stop("The number of score categories for the items should be specified in the argument 'cats'.", call.=FALSE)
+        stop("The number of score categories for the items should be specified in the argument 'cats'.", call. = FALSE)
       }
     }
 
     # when an integer scalar is provided in the cats argument
     # create a vector of the same category numbers
-    if(length(cats) == 1) {
+    if (length(cats) == 1) {
       cats <- rep(cats, ncol(data))
     }
 
     # create an empty item metadata data frame
-    x <- shape_df(item.id=item.id, cats=cats, model=model, default.par=TRUE)
+    x <- shape_df(item.id = item.id, cats = cats, model = model, default.par = TRUE)
 
     # confirm and correct all item metadata information
     x <- confirm_df(x)
@@ -258,7 +260,6 @@ est_item <- function(x=NULL, data, score, D=1, model=NULL, cats=NULL, item.id=NU
 
     # extract model names for all items
     model <- x$model
-
   }
 
   # check the total number of item in the response data set
@@ -268,10 +269,10 @@ est_item <- function(x=NULL, data, score, D=1, model=NULL, cats=NULL, item.id=NU
   nstd <- nrow(data)
 
   # check whether included data are correct
-  if(nrow(x) != nitem) stop("The number of items included in 'x' and 'data' must be the same.", call.=FALSE)
+  if (nrow(x) != nitem) stop("The number of items included in 'x' and 'data' must be the same.", call. = FALSE)
 
   # recode missing values
-  if(!is.na(missing)) {
+  if (!is.na(missing)) {
     data[data == missing] <- NA
   }
 
@@ -282,25 +283,27 @@ est_item <- function(x=NULL, data, score, D=1, model=NULL, cats=NULL, item.id=NU
   loc_allmiss <- which(n.resp == 0L)
 
   # delete items which have all missing responses from the item metadata set
-  if(length(loc_allmiss) > 0L) {
+  if (length(loc_allmiss) > 0L) {
     loc_nomiss <- which(n.resp > 0L)
     x_pre <- x
     x <- x[-loc_allmiss, ]
     model <- x[, 3]
     cats <- x[, 2]
     data <- data[, loc_nomiss]
-    memo2 <- paste0(paste0("item ", loc_allmiss, collapse = ", "),
-                    " is/are excluded in the item parameter estimation because the item(s) has/have no item response data.")
-    warning(memo2, call.=FALSE)
+    memo2 <- paste0(
+      paste0("item ", loc_allmiss, collapse = ", "),
+      " is/are excluded in the item parameter estimation because the item(s) has/have no item response data."
+    )
+    warning(memo2, call. = FALSE)
   } else {
     loc_allmiss <- NULL
   }
 
   # computes the group parameter estimates: mean & var of ability parameters
-  group.par <- c(mu=mean(score), sigma=stats::sd(score))
+  group.par <- c(mu = mean(score), sigma = stats::sd(score))
 
   # transform scores to a vector if the score has other formats
-  if(is.matrix(score) | is.data.frame(score)) {
+  if (is.matrix(score) | is.data.frame(score)) {
     score <- as.numeric(data.matrix(score))
   }
 
@@ -309,13 +312,12 @@ est_item <- function(x=NULL, data, score, D=1, model=NULL, cats=NULL, item.id=NU
 
   # find the location of 1PLM items in which slope parameters should be constrained to be equal
   # also, find the location of items with other models
-  if("1PLM" %in% model & !fix.a.1pl) {
+  if ("1PLM" %in% model & !fix.a.1pl) {
     loc_1p_const <- which(model == "1PLM")
     loc_else <- which(model != "1PLM")
 
     # count the number of 1PLM items to be constrained
     n.1PLM <- length(loc_1p_const)
-
   } else {
     loc_1p_const <- NULL
     loc_else <- 1:nrow(x)
@@ -325,30 +327,35 @@ est_item <- function(x=NULL, data, score, D=1, model=NULL, cats=NULL, item.id=NU
   # record the original location of item parameters to be estimated, and
   # the relocated position of item parameters when computing
   # the variance-covariance matrix of item parameter estimates
-  param_loc <- parloc(x=x, loc_1p_const=loc_1p_const, loc_else=loc_else,
-                      fix.a.1pl=fix.a.1pl, fix.a.gpcm=fix.a.gpcm, fix.g=fix.g)
+  param_loc <- parloc(
+    x = x, loc_1p_const = loc_1p_const, loc_else = loc_else,
+    fix.a.1pl = fix.a.1pl, fix.a.gpcm = fix.a.gpcm, fix.g = fix.g
+  )
 
   # factorize the response values
-  resp <- purrr::map2(.x=data, .y=cats, .f=function(k, m) factor(k, levels=(seq_len(m) - 1)))
+  resp <- purrr::map2(.x = data, .y = cats, .f = function(k, m) factor(k, levels = (seq_len(m) - 1)))
 
   # create a contingency table of score categories for each item
   # and then, transform the table to a matrix format
   std.id <- 1:nstd
   freq.cat <-
-    purrr::map(.x=resp,
-               .f=function(k) {
-                 stats::xtabs(~ std.id + k,
-                              na.action=stats::na.pass, addNA = FALSE) %>%
-                   # as.numeric() %>%
-                   matrix(nrow = length(k))
-               })
+    purrr::map(
+      .x = resp,
+      .f = function(k) {
+        stats::xtabs(~ std.id + k,
+          na.action = stats::na.pass, addNA = FALSE
+        ) %>%
+          # as.numeric() %>%
+          matrix(nrow = length(k))
+      }
+    )
 
   # delete 'resp' object
-  rm(resp, envir=environment(), inherits = FALSE)
+  rm(resp, envir = environment(), inherits = FALSE)
 
-  ##-------------------------------------------------------------------------------------------------------
+  ## -------------------------------------------------------------------------------------------------------
   ## 2. item parameter estimation
-  ##---------------------------------------------------------------
+  ## ---------------------------------------------------------------
   # Item parameter estimation
   # create empty vectors to contain results
   est_par <- NULL
@@ -371,54 +378,67 @@ est_item <- function(x=NULL, data, score, D=1, model=NULL, cats=NULL, item.id=NU
   # (1) DRM 1PL items with the constrained slop
   # (2) other DRM items
   # (3) PRM items
-  if(sum(loc_else) == 0) {drm.else <- NULL} else {drm.else <- loc_else}
-  idx4est <- list(drm.slc = loc_1p_const,
-                  drm.else = drm.else,
-                  prm = idx.prm)
+  if (sum(loc_else) == 0) {
+    drm.else <- NULL
+  } else {
+    drm.else <- loc_else
+  }
+  idx4est <- list(
+    drm.slc = loc_1p_const,
+    drm.else = drm.else,
+    prm = idx.prm
+  )
 
   # add the rowsum margin to the contingency matrix of the DRM items
-  if(!is.null(idx.drm)) {
+  if (!is.null(idx.drm)) {
     freq.cat.drm <-
-      purrr::map(.x = freq.cat[idx.drm],
-                 ~{stats::addmargins(A = .x, margin = 2, quiet = TRUE)})
+      purrr::map(
+        .x = freq.cat[idx.drm],
+        ~ {
+          stats::addmargins(A = .x, margin = 2, quiet = TRUE)
+        }
+      )
     freq.cat[idx.drm] <- freq.cat.drm
 
     # delete 'freq.cat.drm' object
-    rm(freq.cat.drm, envir=environment(), inherits = FALSE)
+    rm(freq.cat.drm, envir = environment(), inherits = FALSE)
   }
 
   # create the lower and upper bounds of the item parameters
   parbd <- lubound(model, cats, n.1PLM, idx4est, fix.a.1pl, fix.g, fix.a.gpcm)
 
   # start estimation
-  if(verbose) {
-    cat("Estimating item parameters...", '\n')
+  if (verbose) {
+    cat("Estimating item parameters...", "\n")
   }
 
   # (1) estimation of DRM items: 1PLM with the constrained slope value
-  if(!is.null(loc_1p_const)) {
-
+  if (!is.null(loc_1p_const)) {
     # prepare input files to estimate the 1PLM item parameters
     f_i <- r_i <- s_i <- array(0, c(nstd, n.1PLM))
-    for(k in 1:n.1PLM) {
+    for (k in 1:n.1PLM) {
       s_i[, k] <- freq.cat[loc_1p_const][[k]][, 1]
       r_i[, k] <- freq.cat[loc_1p_const][[k]][, 2]
       f_i[, k] <- freq.cat[loc_1p_const][[k]][, 3]
     }
 
     # set the starting values
-    if(use.startval) {
+    if (use.startval) {
       startval <-
-        set_startval(pars=elm_item$pars, item=loc_1p_const,
-                     use.startval=TRUE, mod="1PLM",
-                     score.cat=2, fix.a.1pl=FALSE, fix.g=fix.g,
-                     fix.a.gpcm=fix.a.gpcm, n.1PLM=n.1PLM)
+        set_startval(
+          pars = elm_item$pars, item = loc_1p_const,
+          use.startval = TRUE, mod = "1PLM",
+          score.cat = 2, fix.a.1pl = FALSE, fix.g = fix.g,
+          fix.a.gpcm = fix.a.gpcm, n.1PLM = n.1PLM
+        )
     } else {
       startval <-
-        set_startval(pars=elm_item$pars, item=loc_1p_const,
-                     use.startval=FALSE, mod="1PLM",
-                     score.cat=2, fix.a.1pl=FALSE, fix.g=fix.g,
-                     fix.a.gpcm=fix.a.gpcm, n.1PLM=n.1PLM)
+        set_startval(
+          pars = elm_item$pars, item = loc_1p_const,
+          use.startval = FALSE, mod = "1PLM",
+          score.cat = 2, fix.a.1pl = FALSE, fix.g = fix.g,
+          fix.a.gpcm = fix.a.gpcm, n.1PLM = n.1PLM
+        )
     }
 
     # bounds of the item parameters
@@ -426,22 +446,24 @@ est_item <- function(x=NULL, data, score, D=1, model=NULL, cats=NULL, item.id=NU
     upper <- parbd$drm.slc$upper
 
     # parameter estimation
-    est <- estimation1(f_i=f_i, r_i=r_i, s_i, theta=theta, mod="1PLM", D=D, nstd=nstd,
-                       fix.a.1pl=FALSE, n.1PLM=n.1PLM, aprior=aprior, bprior=bprior,
-                       use.aprior=use.aprior, use.bprior=use.bprior,
-                       control=control, startval=startval, lower=lower, upper=upper)
+    est <- estimation1(
+      f_i = f_i, r_i = r_i, s_i, theta = theta, mod = "1PLM", D = D, nstd = nstd,
+      fix.a.1pl = FALSE, n.1PLM = n.1PLM, aprior = aprior, bprior = bprior,
+      use.aprior = use.aprior, use.bprior = use.bprior,
+      control = control, startval = startval, lower = lower, upper = upper
+    )
 
     # extract the results
     # item parameter estimates
     a <- est$pars[1]
     b <- est$par[-1]
-    pars <- purrr::map(1:n.1PLM, .f=function(x) c(a, b[x], NA))
+    pars <- purrr::map(1:n.1PLM, .f = function(x) c(a, b[x], NA))
     est_par <- c(est_par, pars)
 
     # standard errors
     a.se <- est$se[1]
     b.se <- est$se[-1]
-    pars.se <- purrr::map(1:n.1PLM, .f=function(x) c(NA, b.se[x], NA))
+    pars.se <- purrr::map(1:n.1PLM, .f = function(x) c(NA, b.se[x], NA))
     pars.se[[1]][1] <- a.se
     est_se <- c(est_se, pars.se)
 
@@ -450,40 +472,42 @@ est_item <- function(x=NULL, data, score, D=1, model=NULL, cats=NULL, item.id=NU
 
     # convergence indicator
     convergence <- c(convergence, est$convergence)
-    if(est$convergence > 0L) noconv_items <- c(noconv_items, loc_1p_const)
+    if (est$convergence > 0L) noconv_items <- c(noconv_items, loc_1p_const)
 
     # negative loglikelihood value
     objective <- c(objective, est$objective)
-
   }
 
   # all other items
-  if(length(loc_else) >= 1) {
-    for(i in 1:length(loc_else)) {
-
+  if (length(loc_else) >= 1) {
+    for (i in 1:length(loc_else)) {
       # prepare information to estimate item parameters
       mod <- model[loc_else][i]
       score.cat <- cats[loc_else][i]
 
       # in case of a DRM item
-      if(score.cat == 2) {
+      if (score.cat == 2) {
         s_i <- freq.cat[loc_else][[i]][, 1]
         r_i <- freq.cat[loc_else][[i]][, 2]
         f_i <- freq.cat[loc_else][[i]][, 3]
 
         # set the starting values
-        if(use.startval) {
+        if (use.startval) {
           startval <-
-            set_startval(pars=elm_item$pars, item=loc_else[i],
-                         use.startval=TRUE, mod=mod,
-                         score.cat=score.cat, fix.a.1pl=TRUE, fix.g=fix.g,
-                         fix.a.gpcm=fix.a.gpcm, n.1PLM=NULL)
+            set_startval(
+              pars = elm_item$pars, item = loc_else[i],
+              use.startval = TRUE, mod = mod,
+              score.cat = score.cat, fix.a.1pl = TRUE, fix.g = fix.g,
+              fix.a.gpcm = fix.a.gpcm, n.1PLM = NULL
+            )
         } else {
           startval <-
-            set_startval(pars=elm_item$pars, item=loc_else[i],
-                         use.startval=FALSE, mod=mod,
-                         score.cat=score.cat, fix.a.1pl=TRUE, fix.g=fix.g,
-                         fix.a.gpcm=fix.a.gpcm, n.1PLM=NULL)
+            set_startval(
+              pars = elm_item$pars, item = loc_else[i],
+              use.startval = FALSE, mod = mod,
+              score.cat = score.cat, fix.a.1pl = TRUE, fix.g = fix.g,
+              fix.a.gpcm = fix.a.gpcm, n.1PLM = NULL
+            )
         }
 
         # bounds of the item parameters
@@ -492,12 +516,14 @@ est_item <- function(x=NULL, data, score, D=1, model=NULL, cats=NULL, item.id=NU
         upper <- parbd$drm.else[[loc.tmp]]$upper
 
         # parameter estimation
-        est <- estimation1(f_i=f_i, r_i=r_i, s_i=s_i, theta=theta, mod=mod, D=D,
-                           nstd=nstd, fix.a.1pl=ifelse(mod == "1PLM", TRUE, FALSE),
-                           fix.g=fix.g, a.val.1pl=a.val.1pl, g.val=g.val, n.1PLM=NULL,
-                           aprior=aprior, bprior=bprior, gprior=gprior,
-                           use.aprior=use.aprior, use.bprior=use.bprior, use.gprior=use.gprior,
-                           control=control, startval=startval, lower=lower, upper=upper)
+        est <- estimation1(
+          f_i = f_i, r_i = r_i, s_i = s_i, theta = theta, mod = mod, D = D,
+          nstd = nstd, fix.a.1pl = ifelse(mod == "1PLM", TRUE, FALSE),
+          fix.g = fix.g, a.val.1pl = a.val.1pl, g.val = g.val, n.1PLM = NULL,
+          aprior = aprior, bprior = bprior, gprior = gprior,
+          use.aprior = use.aprior, use.bprior = use.bprior, use.gprior = use.gprior,
+          control = control, startval = startval, lower = lower, upper = upper
+        )
 
         # extract the results
         # item parameter estimates
@@ -519,30 +545,33 @@ est_item <- function(x=NULL, data, score, D=1, model=NULL, cats=NULL, item.id=NU
 
         # convergence indicator
         convergence <- c(convergence, est$convergence)
-        if(est$convergence > 0L) noconv_items <- c(noconv_items, loc_else[i])
+        if (est$convergence > 0L) noconv_items <- c(noconv_items, loc_else[i])
 
         # negative loglikelihood value
         objective <- c(objective, est$objective)
-
       }
 
       # in case of a PRM item
-      if(score.cat > 2) {
+      if (score.cat > 2) {
         r_i <- freq.cat[loc_else][[i]]
 
         # set the starting values
-        if(use.startval) {
+        if (use.startval) {
           startval <-
-            set_startval(pars=elm_item$pars, item=loc_else[i],
-                         use.startval=TRUE, mod=mod,
-                         score.cat=score.cat, fix.a.1pl=fix.a.1pl, fix.g=fix.g,
-                         fix.a.gpcm=fix.a.gpcm, n.1PLM=NULL)
+            set_startval(
+              pars = elm_item$pars, item = loc_else[i],
+              use.startval = TRUE, mod = mod,
+              score.cat = score.cat, fix.a.1pl = fix.a.1pl, fix.g = fix.g,
+              fix.a.gpcm = fix.a.gpcm, n.1PLM = NULL
+            )
         } else {
           startval <-
-            set_startval(pars=elm_item$pars, item=loc_else[i],
-                         use.startval=FALSE, mod=mod,
-                         score.cat=score.cat, fix.a.1pl=fix.a.1pl, fix.g=fix.g,
-                         fix.a.gpcm=fix.a.gpcm, n.1PLM=NULL)
+            set_startval(
+              pars = elm_item$pars, item = loc_else[i],
+              use.startval = FALSE, mod = mod,
+              score.cat = score.cat, fix.a.1pl = fix.a.1pl, fix.g = fix.g,
+              fix.a.gpcm = fix.a.gpcm, n.1PLM = NULL
+            )
         }
 
         # bounds of the item parameters
@@ -551,21 +580,23 @@ est_item <- function(x=NULL, data, score, D=1, model=NULL, cats=NULL, item.id=NU
         upper <- parbd$prm[[loc.tmp]]$upper
 
         # parameter estimation
-        est <- estimation1(r_i=r_i, theta=theta, mod=mod, score.cat=score.cat, D=D,
-                           nstd=nstd, fix.a.gpcm=ifelse(mod == "GPCM", fix.a.gpcm, FALSE),
-                           a.val.gpcm=a.val.gpcm, n.1PLM=NULL, aprior=aprior, bprior=bprior,
-                           use.aprior=use.aprior, use.bprior=use.bprior,
-                           control=control, startval=startval, lower=lower, upper=upper)
+        est <- estimation1(
+          r_i = r_i, theta = theta, mod = mod, score.cat = score.cat, D = D,
+          nstd = nstd, fix.a.gpcm = ifelse(mod == "GPCM", fix.a.gpcm, FALSE),
+          a.val.gpcm = a.val.gpcm, n.1PLM = NULL, aprior = aprior, bprior = bprior,
+          use.aprior = use.aprior, use.bprior = use.bprior,
+          control = control, startval = startval, lower = lower, upper = upper
+        )
 
         # extract the results
         # item parameter estimates
         a <- ifelse(mod == "GRM", est$pars[1], ifelse(fix.a.gpcm, a.val.gpcm, est$pars[1]))
-        if(mod == "GRM") {
+        if (mod == "GRM") {
           bs <- est$pars[-1]
         } else {
-          if(fix.a.gpcm) {
+          if (fix.a.gpcm) {
             bs <- est$pars
-          } else{
+          } else {
             bs <- est$pars[-1]
           }
         }
@@ -574,12 +605,12 @@ est_item <- function(x=NULL, data, score, D=1, model=NULL, cats=NULL, item.id=NU
 
         # standard errors
         a.se <- ifelse(mod == "GRM", est$se[1], ifelse(fix.a.gpcm, NA, est$se[1]))
-        if(mod == "GRM") {
+        if (mod == "GRM") {
           bs.se <- est$se[-1]
         } else {
-          if(fix.a.gpcm) {
+          if (fix.a.gpcm) {
             bs.se <- est$se
-          } else{
+          } else {
             bs.se <- est$se[-1]
           }
         }
@@ -591,36 +622,35 @@ est_item <- function(x=NULL, data, score, D=1, model=NULL, cats=NULL, item.id=NU
 
         # convergence indicator
         convergence <- c(convergence, est$convergence)
-        if(est$convergence > 0L) noconv_items <- c(noconv_items, loc_else[i])
+        if (est$convergence > 0L) noconv_items <- c(noconv_items, loc_else[i])
 
         # negative loglikelihood value
         objective <- c(objective, est$objective)
-
       }
     }
   }
 
-  ##---------------------------------------------------------------
+  ## ---------------------------------------------------------------
   # check the convergence of parameter estimation
-  if(sum(convergence) == 0L) {
+  if (sum(convergence) == 0L) {
     note <- "All item parameters were successfully converged."
   } else {
-    note <- paste0(paste0("Item ", sort(noconv_items), collapse=", "), " was(were) not successfully converged.")
+    note <- paste0(paste0("Item ", sort(noconv_items), collapse = ", "), " was(were) not successfully converged.")
   }
 
-  ##---------------------------------------------------------------
+  ## ---------------------------------------------------------------
   # compute the sum of loglikelihood values
   llike <- -sum(objective)
 
-  ##---------------------------------------------------------------
+  ## ---------------------------------------------------------------
   # arrange the estimated item parameters and standard errors
-  par_df <- data.frame(bind.fill(est_par, type="rbind"))
+  par_df <- data.frame(bind.fill(est_par, type = "rbind"))
   par_df$loc <- c(loc_1p_const, loc_else)
   par_df <-
     par_df %>%
     dplyr::arrange("loc") %>%
     dplyr::select(-"loc")
-  se_df <- data.frame(bind.fill(est_se, type="rbind"))
+  se_df <- data.frame(bind.fill(est_se, type = "rbind"))
   se_df$loc <- c(loc_1p_const, loc_else)
   se_df <-
     se_df %>%
@@ -635,34 +665,36 @@ est_item <- function(x=NULL, data, score, D=1, model=NULL, cats=NULL, item.id=NU
   reloc.par <- param_loc$reloc.par
   cov_mat2 <-
     Matrix::sparseMatrix(
-      i=c(row(cov_mat)[reloc.par, ]), j=c(col(cov_mat)[, reloc.par]), x=c(cov_mat)
+      i = c(row(cov_mat)[reloc.par, ]), j = c(col(cov_mat)[, reloc.par]), x = c(cov_mat)
     ) %>%
     as.matrix()
 
   # arrange the estimated item parameters and standard errors
   # when there is any item which have all missing response data
-  if(length(loc_allmiss) > 0L) {
+  if (length(loc_allmiss) > 0L) {
     tmp <-
       x_pre[, -c(1:3)] %>%
-      dplyr::mutate_all(.funs=function(x) NA) %>%
-      purrr::map(.x=1:nrow(x_pre), .f=function(i, .data) as.numeric(.data[i, ]))
+      dplyr::mutate_all(.funs = function(x) NA) %>%
+      purrr::map(.x = 1:nrow(x_pre), .f = function(i, .data) as.numeric(.data[i, ]))
     par_tmp <- se_tmp <- pos_tmp <- tmp
     par_tmp[loc_nomiss] <-
       par_df %>%
-      purrr::map(.x=1:nrow(par_df), .f=function(i, .data) as.numeric(.data[i, ]))
+      purrr::map(.x = 1:nrow(par_df), .f = function(i, .data) as.numeric(.data[i, ]))
     se_tmp[loc_nomiss] <-
       se_df %>%
-      purrr::map(.x=1:nrow(se_df), .f=function(i, .data) as.numeric(.data[i, ]))
+      purrr::map(.x = 1:nrow(se_df), .f = function(i, .data) as.numeric(.data[i, ]))
     pos_tmp[loc_nomiss] <-
       pos_df %>%
-      purrr::map(.x=1:nrow(pos_df), .f=function(i, .data) as.numeric(.data[i, ]))
-    par_df <- data.frame(bind.fill(par_tmp, type="rbind"))
-    se_df <- data.frame(bind.fill(se_tmp, type="rbind"))
-    pos_df <- data.frame(bind.fill(pos_tmp, type="rbind"))
+      purrr::map(.x = 1:nrow(pos_df), .f = function(i, .data) as.numeric(.data[i, ]))
+    par_df <- data.frame(bind.fill(par_tmp, type = "rbind"))
+    se_df <- data.frame(bind.fill(se_tmp, type = "rbind"))
+    pos_df <- data.frame(bind.fill(pos_tmp, type = "rbind"))
   }
 
   # create a full data.frame for the item parameter estimates
-  if(length(loc_allmiss) > 0L) {x <- x_pre}
+  if (length(loc_allmiss) > 0L) {
+    x <- x_pre
+  }
   full_par_df <-
     data.frame(x[, 1:3], par_df) %>%
     confirm_df(g2na = TRUE)
@@ -679,16 +711,16 @@ est_item <- function(x=NULL, data, score, D=1, model=NULL, cats=NULL, item.id=NU
     confirm_df(g2na = TRUE)
 
   # create a full data.frame including both the item parameter estimates and standard error estimates
-  all_df <- data.frame(matrix(NA, nrow=nrow(x), ncol=2*ncol(par_df)))
-  all_df[, seq(1, 2*ncol(par_df), 2)] <- par_df
-  all_df[, seq(2, 2*ncol(par_df), 2)] <- se_df
-  col.names <- rep(NA, 2*ncol(par_df))
-  col.names[seq(1, 2*ncol(par_df), 2)] <- paste0("par.", 1:ncol(par_df))
-  col.names[seq(2, 2*ncol(par_df), 2)] <- paste0("se.", 1:ncol(se_df))
+  all_df <- data.frame(matrix(NA, nrow = nrow(x), ncol = 2 * ncol(par_df)))
+  all_df[, seq(1, 2 * ncol(par_df), 2)] <- par_df
+  all_df[, seq(2, 2 * ncol(par_df), 2)] <- se_df
+  col.names <- rep(NA, 2 * ncol(par_df))
+  col.names[seq(1, 2 * ncol(par_df), 2)] <- paste0("par.", 1:ncol(par_df))
+  col.names[seq(2, 2 * ncol(par_df), 2)] <- paste0("se.", 1:ncol(se_df))
   colnames(all_df) <- col.names
   full_all_df <- data.frame(full_par_df[, 1:3], all_df)
 
-  ##---------------------------------------------------------------
+  ## ---------------------------------------------------------------
   # check end time
   end.time <- Sys.time()
 
@@ -696,21 +728,19 @@ est_item <- function(x=NULL, data, score, D=1, model=NULL, cats=NULL, item.id=NU
   est_time <- round(as.numeric(difftime(end.time, start.time, units = "secs")), 2)
 
   # return results
-  rst <- structure(list(estimates=full_all_df, par.est=full_par_df, se.est=full_se_df, pos.par=full_pos_df, covariance=cov_mat2,
-                        loglikelihood=llike, group.par=group.par, data=data, score=score, scale.D=D, convergence=note, nitem=nitem,
-                        deleted.item=as.numeric(loc_allmiss), npar.est=length(param_loc$reloc.par),
-                        n.response=as.numeric(n.resp), TotalTime=est_time),
-                   class="est_item")
+  rst <- structure(
+    list(
+      estimates = full_all_df, par.est = full_par_df, se.est = full_se_df, pos.par = full_pos_df, covariance = cov_mat2,
+      loglikelihood = llike, group.par = group.par, data = data, score = score, scale.D = D, convergence = note, nitem = nitem,
+      deleted.item = as.numeric(loc_allmiss), npar.est = length(param_loc$reloc.par),
+      n.response = as.numeric(n.resp), TotalTime = est_time
+    ),
+    class = "est_item"
+  )
   rst$call <- cl
 
-  if(verbose) {
-    cat('Estimation is finished.', '\n')
+  if (verbose) {
+    cat("Estimation is finished.", "\n")
   }
   return(rst)
-
-
 }
-
-
-
-
