@@ -43,13 +43,13 @@
 #' ## example 1: when a matrix of probabilities is used as a data set
 #' ## this is an example from Kolen and Brennan (2004, p. 183)
 #' # create a matrix of probabilities of getting correct and incorrect answers for three items
-#' probs <- matrix(c(.74, .73, .82, .26, .27, .18), nrow=3, ncol=2, byrow = FALSE)
+#' probs <- matrix(c(.74, .73, .82, .26, .27, .18), nrow = 3, ncol = 2, byrow = FALSE)
 #'
 #' # create a vector of score categories for the three items
-#' cats <- c(2,2,2)
+#' cats <- c(2, 2, 2)
 #'
 #' # compute the conditional distributions of observed scores
-#' lwrc(prob=probs, cats=cats)
+#' lwrc(prob = probs, cats = cats)
 #'
 #' ## example 2: when a matrix of probabilities is used as a data set
 #' ## with a mixed-format test
@@ -69,7 +69,7 @@
 #' cats <- c(2, 2, 5, 3)
 #'
 #' # compute the conditional distributions of observed scores
-#' lwrc(prob=p, cats=cats)
+#' lwrc(prob = p, cats = cats)
 #'
 #' ## example 3: when a data frame for the item metadata of
 #' ## a mixed-format test is used.
@@ -77,30 +77,30 @@
 #' flex_prm <- system.file("extdata", "flexmirt_sample-prm.txt", package = "irtQ")
 #'
 #' # read item parameters and transform them to item metadata
-#' x <- bring.flexmirt(file=flex_prm, "par")$Group1$full_df
+#' x <- bring.flexmirt(file = flex_prm, "par")$Group1$full_df
 #'
 #' # compute the conditional distributions of observed scores
-#' lwrc(x=x, theta=seq(-4, 4, 0.2), D=1)
+#' lwrc(x = x, theta = seq(-4, 4, 0.2), D = 1)
 #'
 #' @export
-lwrc <- function(x=NULL, theta, prob=NULL, cats, D=1) {
-
-  if(is.null(x)) {
-
+lwrc <- function(x = NULL, theta, prob = NULL, cats, D = 1) {
+  if (is.null(x)) {
     max.cat <- ncol(prob)
     n.cats <- length(cats)
     n.prob <- nrow(prob)
 
     logic <- is.numeric(prob)
-    if(!logic) stop("All numbers in 'prob' should be numeric.", call.=FALSE)
+    if (!logic) stop("All numbers in 'prob' should be numeric.", call. = FALSE)
 
-    if(n.prob != n.cats) {
-      stop(paste0("There are ", n.prob, " items in the probability matrix (or data.frame), ",
-                  "whereas there are ", n.cats, " items in the category vector."), call.=FALSE)
+    if (n.prob != n.cats) {
+      stop(paste0(
+        "There are ", n.prob, " items in the probability matrix (or data.frame), ",
+        "whereas there are ", n.cats, " items in the category vector."
+      ), call. = FALSE)
     }
 
-    if(min(cats) < 2) {
-      stop("Minimum number of categories for each item is 2", call.=FALSE)
+    if (min(cats) < 2) {
+      stop("Minimum number of categories for each item is 2", call. = FALSE)
     }
 
     # Probabilities for each category at the 1st item
@@ -110,19 +110,18 @@ lwrc <- function(x=NULL, theta, prob=NULL, cats, D=1) {
     tmp <- c()
 
     # Possible observed score range for a first item
-    obs.range <- 0:(cats[1]-1)
+    obs.range <- 0:(cats[1] - 1)
 
     # proceed the further analysis when # of the items > 1
-    if(n.cats > 1) {
-
+    if (n.cats > 1) {
       # Calculate probabilities to earn an observed score by accumulating over remaining items
-      for(j in 2:n.prob) {  # should start from a 2nd item
+      for (j in 2:n.prob) { # should start from a 2nd item
 
         # Probability to earn zero score. This is a special case
         tmp[1] <- p[1] * prob[j, 1]
 
         # The range of category scores for an added item
-        cat.range <- 0:(cats[j]-1)
+        cat.range <- 0:(cats[j] - 1)
 
         # Possible minimum and maximum observed scores when the item is added
         # but, except zero and perfect score
@@ -151,12 +150,12 @@ lwrc <- function(x=NULL, theta, prob=NULL, cats, D=1) {
 
         # Final probability to earn the observed score
         prob.score <- c()
-        for(k in 1:length.score) {
+        for (k in 1:length.score) {
           tmp.cols <- which(cols[, k])
           tmp.diff <- poss.diff[tmp.cols, k]
           prob.score[k] <- sum(p[(tmp.diff + 1)] * prob[j, tmp.cols])
         }
-        tmp[1+poss.score] <- prob.score
+        tmp[1 + poss.score] <- prob.score
 
         # Probability to earn perfect score. This is a special case.
         tmp[max.s + 2] <- p[length(p)] * prob[j, cats[j]]
@@ -166,21 +165,17 @@ lwrc <- function(x=NULL, theta, prob=NULL, cats, D=1) {
 
         # Update the range of possible observed scores
         # obs.range <- (min.s-1):(max.s+1)
-        obs.range <- c((min.s-1), poss.score, (max.s+1))
+        obs.range <- c((min.s - 1), poss.score, (max.s + 1))
 
         # Reset the temporary vector
         tmp <- c()
-
       }
-
     }
 
     # return the results
     names(p) <- paste0("score.", obs.range)
     p
-
   } else {
-
     # confirm and correct all item metadata information
     x <- confirm_df(x)
 
@@ -188,33 +183,32 @@ lwrc <- function(x=NULL, theta, prob=NULL, cats, D=1) {
     n.theta <- length(theta)
 
     # prepare the probability matrices
-    prepdat <- prep4lw2(x=x, theta=theta, D=D)
+    prepdat <- prep4lw2(x = x, theta = theta, D = D)
 
     # apply the recursion formula
-    p <- lwRecurive(prob.cats=prepdat$prob.cat,
-                    cats=prepdat$cats,
-                    n.theta=n.theta)
+    p <- lwRecurive(
+      prob.cats = prepdat$prob.cat,
+      cats = prepdat$cats,
+      n.theta = n.theta
+    )
 
     # return the results
     p
-
   }
-
 }
 
 
-###--------------------------------------------------------------------------------------------------------------------
+### --------------------------------------------------------------------------------------------------------------------
 # "lwRecursive" function
 # Arg:
 # prob.cats: (list) each element of a list includes a probability matrix (or data.frame) for an item.
-#					In each probability matrix, rows indicate theta values (or weights) and columns indicate
-#					score categories. Thus, each elements in the matrix represents the probability that a person
-#					who has a certain ability earns a certain score.
+# 					In each probability matrix, rows indicate theta values (or weights) and columns indicate
+# 					score categories. Thus, each elements in the matrix represents the probability that a person
+# 					who has a certain ability earns a certain score.
 # cats: (vector) containes score categories for all items
 # n.theta: (integer) number of thetas
 #' @importFrom Rfast rowsums
 lwRecurive <- function(prob.cats, cats, n.theta) {
-
   # if(length(unique(sapply(prob.cats, nrow))) != 1L) {
   #   stop("At least, one probability matrix (or data.frame) has the difference number of rows across all marices in a list", call.=FALSE)
   # }
@@ -224,8 +218,8 @@ lwRecurive <- function(prob.cats, cats, n.theta) {
   #               "whereas there are ", length(cats), " items in the category vector."), call.=FALSE)
   # }
 
-  if(min(cats) < 2) {
-    stop("Minimum number of categories for each item is 2", call.=FALSE)
+  if (min(cats) < 2) {
+    stop("Minimum number of categories for each item is 2", call. = FALSE)
   }
 
   # Probabilities for each category at 1st item
@@ -235,24 +229,22 @@ lwRecurive <- function(prob.cats, cats, n.theta) {
   # n.theta <- nrow(prob.cats[[1]])
 
   # possible observed score range for a first item
-  obs.range <- 0:(cats[1]-1)
+  obs.range <- 0:(cats[1] - 1)
 
   # proceed the further analysis when # of the items > 1
-  if(length(cats) > 1) {
-
+  if (length(cats) > 1) {
     # create a temporary matrix to contain all probabilities
-    tScore.range <- 0:sum(cats-1)
+    tScore.range <- 0:sum(cats - 1)
     # tmp <- matrix(0, nrow=n.theta, ncol=length(tScore.range))
     tmp <- array(0, c(n.theta, length(tScore.range)))
 
     # Calculate probabilities to earn an observed score by accumulating over remaining items
-    for(j in 2:length(cats)) {
-
+    for (j in 2:length(cats)) {
       # Probability to earn zero score. This is a special case.
       tmp[, 1] <- p[, 1] * prob.cats[[j]][, 1]
 
       # The range of category scores for an added item
-      cat.range <- 0:(cats[j]-1)
+      cat.range <- 0:(cats[j] - 1)
 
       # Possible minimum and maximum observed scores when the item is added
       # but, except zero and perfect score
@@ -283,10 +275,10 @@ lwRecurive <- function(prob.cats, cats, n.theta) {
 
       # Final probability to earn the observed score
       prob.score <- array(0, c(n.theta, length.score))
-      for(k in 1:length.score) {
+      for (k in 1:length.score) {
         tmp.cols <- cols[, k]
         tmp.diff <- poss.diff[tmp.cols, k]
-        prob.score[, k] <- Rfast::rowsums(p[, (tmp.diff + 1), drop=FALSE] * prob.cats[[j]][, tmp.cols, drop=FALSE])
+        prob.score[, k] <- Rfast::rowsums(p[, (tmp.diff + 1), drop = FALSE] * prob.cats[[j]][, tmp.cols, drop = FALSE])
       }
       tmp[, 1 + poss.score] <- prob.score
 
@@ -309,14 +301,12 @@ lwRecurive <- function(prob.cats, cats, n.theta) {
 
       # Update the range of possible observed scores
       # obs.range <- (min.s-1):(max.s+1)
-      obs.range <- c((min.s-1), poss.score, (max.s+1))
+      obs.range <- c((min.s - 1), poss.score, (max.s + 1))
 
       # Update probabilities
       # p <- tmp[, 1:length(obs.range), drop=FALSE]
-      p <- tmp[, obs.range+1, drop=FALSE]
-
+      p <- tmp[, obs.range + 1, drop = FALSE]
     }
-
   }
 
   # return the results
@@ -324,25 +314,20 @@ lwRecurive <- function(prob.cats, cats, n.theta) {
   colnames(p) <- paste0("score.", obs.range)
   rownames(p) <- paste0("theta.", 1:n.theta)
   t(p)
-
 }
 
 # "prep4lw2" function
 # This function is used only for "lwrc" function
 prep4lw2 <- function(x, theta, D) {
-
   # break down the item metadata into several components
   elm_item <- breakdown(x)
 
   # compute category probabilities for all items
-  prob.cats <- trace(elm_item, theta, D=D, tcc=FALSE)$prob.cats
+  prob.cats <- trace(elm_item, theta, D = D, tcc = FALSE)$prob.cats
 
   # extract score categories for all items
   cats <- elm_item$cats
 
   # Return results
-  list(prob.cats=prob.cats, cats=cats)
-
+  list(prob.cats = prob.cats, cats = cats)
 }
-
-
