@@ -27,14 +27,14 @@
 #' flex_prm <- system.file("extdata", "flexmirt_sample-prm.txt", package = "irtQ")
 #'
 #' # read item parameters and transform them to item metadata
-#' test_flex <- bring.flexmirt(file=flex_prm, "par")$Group1$full_df
+#' test_flex <- bring.flexmirt(file = flex_prm, "par")$Group1$full_df
 #'
 #' # set theta values
 #' theta <- seq(-3, 3, 0.5)
 #'
 #' # compute the item category probabilities and item/test
 #' # characteristic functions given the theta values
-#' traceline(x=test_flex, theta, D=1)
+#' traceline(x = test_flex, theta, D = 1)
 #'
 #' @export
 traceline <- function(x, ...) UseMethod("traceline")
@@ -42,10 +42,9 @@ traceline <- function(x, ...) UseMethod("traceline")
 #' @describeIn traceline Default method to compute the item category probabilities, item characteristic function, and
 #' test characteristic function for a data frame \code{x} containing the item metadata.
 #' @importFrom Rfast rowsums
+#' @import dplyr
 #' @export
 traceline.default <- function(x, theta, D = 1, ...) {
-
-
   # confirm and correct all item metadata information
   x <- confirm_df(x)
 
@@ -64,44 +63,44 @@ traceline.default <- function(x, theta, D = 1, ...) {
   n.item <- sum(length(idx.drm), length(idx.prm))
 
   # make the empty list and data frame to contain icc and tcc
-  prob.cats <- vector('list', n.item)
+  prob.cats <- vector("list", n.item)
   icc_df <- array(NA, c(n.theta, n.item))
   names(prob.cats) <- x$id
   colnames(icc_df) <- x$id
 
   # For DRM items
-  if(!is.null(idx.drm)) {
-
+  if (!is.null(idx.drm)) {
     # compute the probabilities of correct answers
-    p.mat <- drm(theta=theta, a=elm_item$pars[idx.drm, 1],
-                 b=elm_item$pars[idx.drm, 2], g=elm_item$pars[idx.drm, 3],
-                 D=D)
+    p.mat <- drm(
+      theta = theta, a = elm_item$pars[idx.drm, 1],
+      b = elm_item$pars[idx.drm, 2], g = elm_item$pars[idx.drm, 3],
+      D = D
+    )
     p.vec <- c(p.mat)
     q.vec <- 1 - p.vec
 
     # split the probabilities into each item group
     prob.drm <-
-      split.data.frame(cbind(resp.0 = q.vec, resp.1 = p.vec),
-                       rep(idx.drm, each=n.theta))
+      split.data.frame(
+        cbind(resp.0 = q.vec, resp.1 = p.vec),
+        rep(idx.drm, each = n.theta)
+      )
 
     # fill the empty list
     prob.cats[idx.drm] <- prob.drm
 
     # insert icc
     icc_df[, idx.drm] <- p.mat
-
   }
 
   # For PRM items
-  if(!is.null(idx.prm)) {
-
+  if (!is.null(idx.prm)) {
     # check what poly models were used
     pr.mod <- unique(elm_item$model[idx.prm])
 
     # check the maximum score category
     max.cats <- max(elm_item$cats) - 1
-    for(mod in pr.mod) {
-
+    for (mod in pr.mod) {
       # extract the response, model, and item parameters
       lg.prm <- elm_item$model == mod
       par.tmp <- elm_item$par[lg.prm, , drop = FALSE]
@@ -114,40 +113,45 @@ traceline.default <- function(x, theta, D = 1, ...) {
 
       # compute the probabilities of endorsing each score category
       P.all <-
-        info_prm(theta=theta, a=a, d=d, D=D, pr.model=mod,
-                 grad=FALSE, info=FALSE)$P
+        info_prm(
+          theta = theta, a = a, d = d, D = D, pr.model = mod,
+          grad = FALSE, info = FALSE
+        )$P
       colnames(P.all) <- paste0("resp.", 0:max.cats)
       prob.cats[idx.tmp] <-
-        split.data.frame(P.all,
-                         rep(1:length(a), n.theta)) %>%
-        purrr::map2(.y = cat.tmp,
-                    .f = ~{.x[, 1:(.y)]})
+        split.data.frame(
+          P.all,
+          rep(1:length(a), n.theta)
+        ) %>%
+        purrr::map2(
+          .y = cat.tmp,
+          .f = ~ {
+            .x[, 1:(.y)]
+          }
+        )
 
       # insert icc
       icc_df[, idx.tmp] <-
         matrix(P.all %*% c(0:max.cats), nrow = n.theta, byrow = TRUE)
-
     }
-
   }
 
   # compute tcc
   tcc.vec <- Rfast::rowsums(icc_df)
 
   # return results
-  rst <- list(prob.cats=prob.cats, icc=icc_df, tcc=tcc.vec, theta=theta)
+  rst <- list(prob.cats = prob.cats, icc = icc_df, tcc = tcc.vec, theta = theta)
   class(rst) <- "traceline"
   rst
-
 }
 
 
 
 #' @describeIn traceline An object created by the function \code{\link{est_item}}.
 #' @importFrom Rfast rowsums
+#' @import dplyr
 #' @export
 traceline.est_item <- function(x, theta, ...) {
-
   # extract information from an object
   D <- x$scale.D
   x <- x$par.est
@@ -170,44 +174,44 @@ traceline.est_item <- function(x, theta, ...) {
   n.item <- sum(length(idx.drm), length(idx.prm))
 
   # make the empty list and data frame to contain icc and tcc
-  prob.cats <- vector('list', n.item)
+  prob.cats <- vector("list", n.item)
   icc_df <- array(NA, c(n.theta, n.item))
   names(prob.cats) <- x$id
   colnames(icc_df) <- x$id
 
   # For DRM items
-  if(!is.null(idx.drm)) {
-
+  if (!is.null(idx.drm)) {
     # compute the probabilities of correct answers
-    p.mat <- drm(theta=theta, a=elm_item$pars[idx.drm, 1],
-                 b=elm_item$pars[idx.drm, 2], g=elm_item$pars[idx.drm, 3],
-                 D=D)
+    p.mat <- drm(
+      theta = theta, a = elm_item$pars[idx.drm, 1],
+      b = elm_item$pars[idx.drm, 2], g = elm_item$pars[idx.drm, 3],
+      D = D
+    )
     p.vec <- c(p.mat)
     q.vec <- 1 - p.vec
 
     # split the probabilities into each item group
     prob.drm <-
-      split.data.frame(cbind(resp.0 = q.vec, resp.1 = p.vec),
-                       rep(idx.drm, each=n.theta))
+      split.data.frame(
+        cbind(resp.0 = q.vec, resp.1 = p.vec),
+        rep(idx.drm, each = n.theta)
+      )
 
     # fill the empty list
     prob.cats[idx.drm] <- prob.drm
 
     # insert icc
     icc_df[, idx.drm] <- p.mat
-
   }
 
   # For PRM items
-  if(!is.null(idx.prm)) {
-
+  if (!is.null(idx.prm)) {
     # check what poly models were used
     pr.mod <- unique(elm_item$model[idx.prm])
 
     # check the maximum score category
     max.cats <- max(elm_item$cats) - 1
-    for(mod in pr.mod) {
-
+    for (mod in pr.mod) {
       # extract the response, model, and item parameters
       lg.prm <- elm_item$model == mod
       par.tmp <- elm_item$par[lg.prm, , drop = FALSE]
@@ -220,39 +224,44 @@ traceline.est_item <- function(x, theta, ...) {
 
       # compute the probabilities of endorsing each score category
       P.all <-
-        info_prm(theta=theta, a=a, d=d, D=D, pr.model=mod,
-                 grad=FALSE, info=FALSE)$P
+        info_prm(
+          theta = theta, a = a, d = d, D = D, pr.model = mod,
+          grad = FALSE, info = FALSE
+        )$P
       colnames(P.all) <- paste0("resp.", 0:max.cats)
       prob.cats[idx.tmp] <-
-        split.data.frame(P.all,
-                         rep(1:length(a), n.theta)) %>%
-        purrr::map2(.y = cat.tmp,
-                    .f = ~{.x[, 1:(.y)]})
+        split.data.frame(
+          P.all,
+          rep(1:length(a), n.theta)
+        ) %>%
+        purrr::map2(
+          .y = cat.tmp,
+          .f = ~ {
+            .x[, 1:(.y)]
+          }
+        )
 
       # insert icc
       icc_df[, idx.tmp] <-
         matrix(P.all %*% c(0:max.cats), nrow = n.theta, byrow = TRUE)
-
     }
-
   }
 
   # compute tcc
   tcc.vec <- Rfast::rowsums(icc_df)
 
   # return results
-  rst <- list(prob.cats=prob.cats, icc=icc_df, tcc=tcc.vec, theta=theta)
+  rst <- list(prob.cats = prob.cats, icc = icc_df, tcc = tcc.vec, theta = theta)
   class(rst) <- "traceline"
   rst
-
 }
 
 
 #' @describeIn traceline An object created by the function \code{\link{est_irt}}.
 #' @importFrom Rfast rowsums
+#' @import dplyr
 #' @export
 traceline.est_irt <- function(x, theta, ...) {
-
   # extract information from an object
   D <- x$scale.D
   x <- x$par.est
@@ -275,44 +284,44 @@ traceline.est_irt <- function(x, theta, ...) {
   n.item <- sum(length(idx.drm), length(idx.prm))
 
   # make the empty list and data frame to contain icc and tcc
-  prob.cats <- vector('list', n.item)
+  prob.cats <- vector("list", n.item)
   icc_df <- array(NA, c(n.theta, n.item))
   names(prob.cats) <- x$id
   colnames(icc_df) <- x$id
 
   # For DRM items
-  if(!is.null(idx.drm)) {
-
+  if (!is.null(idx.drm)) {
     # compute the probabilities of correct answers
-    p.mat <- drm(theta=theta, a=elm_item$pars[idx.drm, 1],
-                 b=elm_item$pars[idx.drm, 2], g=elm_item$pars[idx.drm, 3],
-                 D=D)
+    p.mat <- drm(
+      theta = theta, a = elm_item$pars[idx.drm, 1],
+      b = elm_item$pars[idx.drm, 2], g = elm_item$pars[idx.drm, 3],
+      D = D
+    )
     p.vec <- c(p.mat)
     q.vec <- 1 - p.vec
 
     # split the probabilities into each item group
     prob.drm <-
-      split.data.frame(cbind(resp.0 = q.vec, resp.1 = p.vec),
-                       rep(idx.drm, each=n.theta))
+      split.data.frame(
+        cbind(resp.0 = q.vec, resp.1 = p.vec),
+        rep(idx.drm, each = n.theta)
+      )
 
     # fill the empty list
     prob.cats[idx.drm] <- prob.drm
 
     # insert icc
     icc_df[, idx.drm] <- p.mat
-
   }
 
   # For PRM items
-  if(!is.null(idx.prm)) {
-
+  if (!is.null(idx.prm)) {
     # check what poly models were used
     pr.mod <- unique(elm_item$model[idx.prm])
 
     # check the maximum score category
     max.cats <- max(elm_item$cats) - 1
-    for(mod in pr.mod) {
-
+    for (mod in pr.mod) {
       # extract the response, model, and item parameters
       lg.prm <- elm_item$model == mod
       par.tmp <- elm_item$par[lg.prm, , drop = FALSE]
@@ -325,31 +334,36 @@ traceline.est_irt <- function(x, theta, ...) {
 
       # compute the probabilities of endorsing each score category
       P.all <-
-        info_prm(theta=theta, a=a, d=d, D=D, pr.model=mod,
-                 grad=FALSE, info=FALSE)$P
+        info_prm(
+          theta = theta, a = a, d = d, D = D, pr.model = mod,
+          grad = FALSE, info = FALSE
+        )$P
       colnames(P.all) <- paste0("resp.", 0:max.cats)
       prob.cats[idx.tmp] <-
-        split.data.frame(P.all,
-                         rep(1:length(a), n.theta)) %>%
-        purrr::map2(.y = cat.tmp,
-                    .f = ~{.x[, 1:(.y)]})
+        split.data.frame(
+          P.all,
+          rep(1:length(a), n.theta)
+        ) %>%
+        purrr::map2(
+          .y = cat.tmp,
+          .f = ~ {
+            .x[, 1:(.y)]
+          }
+        )
 
       # insert icc
       icc_df[, idx.tmp] <-
         matrix(P.all %*% c(0:max.cats), nrow = n.theta, byrow = TRUE)
-
     }
-
   }
 
   # compute tcc
   tcc.vec <- Rfast::rowsums(icc_df)
 
   # return results
-  rst <- list(prob.cats=prob.cats, icc=icc_df, tcc=tcc.vec, theta=theta)
+  rst <- list(prob.cats = prob.cats, icc = icc_df, tcc = tcc.vec, theta = theta)
   class(rst) <- "traceline"
   rst
-
 }
 
 
@@ -357,9 +371,8 @@ traceline.est_irt <- function(x, theta, ...) {
 # This function is used in item parameter estimation
 #' @importFrom purrr map2
 #' @importFrom Rfast rowsums
-trace <- function(elm_item, theta, D = 1, tcc=TRUE) {
-
-
+#' @import dplyr
+trace <- function(elm_item, theta, D = 1, tcc = TRUE) {
   # set indices of the DRM and PRM items
   idx.all <- idxfinder(elm_item)
   idx.drm <- idx.all$idx.drm
@@ -372,8 +385,8 @@ trace <- function(elm_item, theta, D = 1, tcc=TRUE) {
   n.item <- sum(length(idx.drm), length(idx.prm))
 
   # make the empty list and data frame to contain icc and tcc
-  prob.cats <- vector('list', n.item)
-  if(tcc) {
+  prob.cats <- vector("list", n.item)
+  if (tcc) {
     # icc_df <- matrix(NA, nrow=n.theta, ncol=n.item)
     icc_df <- array(NA, c(n.theta, n.item))
   } else {
@@ -381,12 +394,13 @@ trace <- function(elm_item, theta, D = 1, tcc=TRUE) {
   }
 
   # For DRM items
-  if(!is.null(idx.drm)) {
-
+  if (!is.null(idx.drm)) {
     # compute the probabilities of correct answers
-    p.mat <- drm(theta=theta, a=elm_item$pars[idx.drm, 1],
-                 b=elm_item$pars[idx.drm, 2], g=elm_item$pars[idx.drm, 3],
-                 D=D)
+    p.mat <- drm(
+      theta = theta, a = elm_item$pars[idx.drm, 1],
+      b = elm_item$pars[idx.drm, 2], g = elm_item$pars[idx.drm, 3],
+      D = D
+    )
     p.vec <- c(p.mat)
     q.vec <- 1 - p.vec
 
@@ -395,29 +409,28 @@ trace <- function(elm_item, theta, D = 1, tcc=TRUE) {
     #   split.data.frame(cbind(resp.0 = q.vec, resp.1 = p.vec),
     #                    rep(idx.drm, each=n.theta))
     prob.drm <-
-      split.data.frame(cbind(q.vec, p.vec),
-                       rep(idx.drm, each=n.theta))
+      split.data.frame(
+        cbind(q.vec, p.vec),
+        rep(idx.drm, each = n.theta)
+      )
 
     # fill the empty list
     prob.cats[idx.drm] <- prob.drm
 
     # if tcc = TRUE
-    if(tcc) {
+    if (tcc) {
       icc_df[, idx.drm] <- p.mat
     }
-
   }
 
   # For PRM items
-  if(!is.null(idx.prm)) {
-
+  if (!is.null(idx.prm)) {
     # check what poly models were used
     pr.mod <- unique(elm_item$model[idx.prm])
 
     # check the maximum score category
     max.cats <- max(elm_item$cats) - 1
-    for(mod in pr.mod) {
-
+    for (mod in pr.mod) {
       # extract the response, model, and item parameters
       lg.prm <- elm_item$model == mod
       par.tmp <- elm_item$par[lg.prm, , drop = FALSE]
@@ -430,33 +443,38 @@ trace <- function(elm_item, theta, D = 1, tcc=TRUE) {
 
       # compute the probabilities of endorsing each score category
       P.all <-
-        info_prm(theta=theta, a=a, d=d, D=D, pr.model=mod,
-                 grad=FALSE, info=FALSE)$P
+        info_prm(
+          theta = theta, a = a, d = d, D = D, pr.model = mod,
+          grad = FALSE, info = FALSE
+        )$P
       prob.cats[idx.tmp] <-
-        split.data.frame(P.all,
-                         rep(1:length(a), n.theta)) %>%
-        purrr::map2(.y = cat.tmp,
-                    .f = ~{.x[, 1:(.y)]})
+        split.data.frame(
+          P.all,
+          rep(1:length(a), n.theta)
+        ) %>%
+        purrr::map2(
+          .y = cat.tmp,
+          .f = ~ {
+            .x[, 1:(.y)]
+          }
+        )
 
       # if tcc = TRUE
-      if(tcc) {
+      if (tcc) {
         icc_df[, idx.tmp] <-
           matrix(P.all %*% c(0:max.cats), nrow = n.theta, byrow = TRUE)
       }
-
     }
-
   }
 
   # if tcc = TRUE
-  if(tcc) {
+  if (tcc) {
     tcc.vec <- Rfast::rowsums(icc_df)
   } else {
     tcc.vec <- NULL
   }
 
   # return results
-  rst <- list(prob.cats=prob.cats, icc=icc_df, tcc=tcc.vec, theta=theta)
+  rst <- list(prob.cats = prob.cats, icc = icc_df, tcc = tcc.vec, theta = theta)
   rst
-
 }
